@@ -50,9 +50,9 @@ class TonicAuthentication():
         a valid signature has been supplied using Firebase authentication.
         """
 
-        firebase_token = self.get_token(request)
+        prefix, token = self.get_token(request)
 
-        decoded_token = self.decode_token(firebase_token)
+        decoded_token = self.decode_token(token, prefix)
 
         return (decoded_token, None)
 
@@ -61,29 +61,41 @@ class TonicAuthentication():
         Parse Authorization header and retrieve JWT
         """
         authorization_header = self.get_authorization_header(request).split()
-        auth_header_prefix = \
-            settings_auth["FIREBASE_AUTH_HEADER_PREFIX"].lower()
+
+        if 'AUTH_HEADER_PREFIX' in settings_auth.keys():
+            auth_header_prefix = settings_auth["AUTH_HEADER_PREFIX"]
+        else:
+            auth_header_prefix = settings_auth["FIREBASE_AUTH_HEADER_PREFIX"]
 
         if not authorization_header or len(authorization_header) != 2:
             raise exceptions.AuthenticationFailed(
-                'Invalid Authorization header format, expecting: JWT <token>.'
+                'Invalid Authorization header format, expecting: <prefix> <token>.'
             )
 
-        if smart_text(authorization_header[0].lower()) != auth_header_prefix:
+        if smart_text(authorization_header[0].upper()) not in auth_header_prefix:
             raise exceptions.AuthenticationFailed(
-                'Invalid Authorization header prefix, expecting: JWT.'
+                f'Invalid Authorization header prefix, expecting one of this options: {auth_header_prefix}.'
             )
 
-        return authorization_header[1]
+        return smart_text(authorization_header[0].upper()), authorization_header[1]
 
-    def decode_token(self, firebase_token):
+    def decode_token(self, token, prefix):
         """
-        Attempt to verify JWT from Authorization header with Firebase and
-        return the decoded token
+        Attempt to verify JWT from Authorization header with Firebase or others authentications methods
+        Return the decoded token
         """
+        if prefix != 'JWT':
+            if token.decode('utf-8') in settings_auth["TONIC_WEB_TOKEN"]:
+                return {
+                    'name': 'Tonic Admin',
+                    'is_admin': True,
+                    'user_id': '9999999',
+                    'uid': '9999999'
+                }
+            raise exceptions.AuthenticationFailed('Token is invalid.')
         try:
             return auth.verify_id_token(
-                firebase_token,
+                token,
                 check_revoked=settings_auth["FIREBASE_CHECK_JWT_REVOKED"]
             )
         except ValueError as exc:
@@ -102,3 +114,6 @@ class TonicAuthentication():
                 )
             else:
                 raise exceptions.AuthenticationFailed('Token is invalid.')
+
+    def authenticate_header(self, request):
+        return request
